### Date Picker

/// tab | Result
    new: true
```{.textual path="docs/examples/date_picker_example.py"}
```
///

/// tab | Source
```python
--8<-- "docs/examples/date_picker_example.py"
```
///

### Date Range

/// tab | Result
    new: true
```{.textual path="docs/examples/date_range_example.py"}
```
///

/// tab | Source
```python
--8<-- "docs/examples/date_range_example.py"
```
///

### Date Select

/// tab | Result
    new: true
```{.textual path="docs/examples/date_select_example.py"}
```
///

/// tab | Source
```python
--8<-- "docs/examples/date_select_example.py"
```
///

### DateTime Range Picker

/// tab | Result
    new: true
```{.textual path="docs/examples/dt_range_example.py"}
```
///

/// tab | Source
```python
--8<-- "docs/examples/dt_range_example.py"
```
///

### Single Line Picker

/// tab | Result
    new: true
```{.textual path="docs/examples/mini_picker_example.py"}
```
///

/// tab | Source
```python
--8<-- "docs/examples/mini_picker_example.py"
```
///
